@@ -14,13 +14,13 @@
 #include <iomanip>
 
 #include "solver-cache.h"
-
+#include "constants.h"
 
 // [[Rcpp::export(".sum_qn_q")]]
 Rcpp::List sum_qn_q(const Eigen::Map<Eigen::SparseMatrix<double> > &M,
                     const Eigen::Map<Eigen::SparseMatrix<double> > &M2,
                     const Eigen::VectorXd &q,
-                    Rcpp::NumericVector t)
+                    const Rcpp::NumericVector &t)
 {
   int n = t.size();
 
@@ -29,18 +29,30 @@ Rcpp::List sum_qn_q(const Eigen::Map<Eigen::SparseMatrix<double> > &M,
   Eigen::SparseLU<Eigen::SparseMatrix<double> > solver;
 
   solver.compute(M2);
+  if(solver.info() != Eigen::Success) {
+    Rcpp::stop("Decomposition failed in sum_qn_q");
+  }
 
-  Rcpp::List res = Rcpp::List::create();
+  Rcpp::List res(n - 1);
 
   for(int i = 1; i < n; i++) {
-    for(int j = t[i - 1]; j < t[i]; j++) {
-      if(j % 1000 == 0) Rcpp::checkUserInterrupt();
-        q2 = M * q2;
+    int t_start = t[i - 1];
+    int t_end = t[i];
+
+    for(int j = t_start; j < t_end; j++) {
+      if(j % INTERRUPT_CHECK_INTERVAL == 0) {
+        Rcpp::checkUserInterrupt();
       }
 
-    Eigen::VectorXd time_res = solver.solve(q - q2);
+      q2 = M * q2;
+    }
 
-    res.push_back(time_res, std::to_string((int)t[i]));
+    Eigen::VectorXd time_res = solver.solve(q - q2);
+    if(solver.info() != Eigen::Success) {
+      Rcpp::stop("Solver failed in sum_qn_q");
+    }
+
+    res[i - 1] = Rcpp::wrap(time_res);
   }
 
   return res;
@@ -48,9 +60,9 @@ Rcpp::List sum_qn_q(const Eigen::Map<Eigen::SparseMatrix<double> > &M,
 
 // [[Rcpp::export(".sum_qn_q_iter")]]
 Rcpp::List sum_qn_q_iter(const Eigen::Map<Eigen::SparseMatrix<double> > &M,
-                    const Eigen::Map<Eigen::SparseMatrix<double> > &M2,
-                    const Eigen::VectorXd &q,
-                    Rcpp::NumericVector t)
+                         const Eigen::Map<Eigen::SparseMatrix<double> > &M2,
+                         const Eigen::VectorXd &q,
+                         const Rcpp::NumericVector &t)
 {
   int n = t.size();
 
@@ -59,60 +71,72 @@ Rcpp::List sum_qn_q_iter(const Eigen::Map<Eigen::SparseMatrix<double> > &M,
   Eigen::BiCGSTAB<Eigen::SparseMatrix<double>, Eigen::IncompleteLUT<double> > solver;
 
   solver.compute(M2);
+  if(solver.info() != Eigen::Success) {
+    Rcpp::stop("Decomposition failed in sum_qn_q_iter");
+  }
 
-  Rcpp::List res = Rcpp::List::create();
+  Rcpp::List res(n - 1);
 
   for(int i = 1; i < n; i++) {
-    for(int j = t[i - 1]; j < t[i]; j++) {
-      if(j % 1000 == 0) Rcpp::checkUserInterrupt();
+    int t_start = t[i - 1];
+    int t_end = t[i];
+
+    for(int j = t_start; j < t_end; j++) {
+      if(j % INTERRUPT_CHECK_INTERVAL == 0) {
+        Rcpp::checkUserInterrupt();
+      }
+
       q2 = M * q2;
     }
 
     Eigen::VectorXd time_res = solver.solve(q - q2);
+    if(solver.info() != Eigen::Success) {
+      Rcpp::stop("Solver failed in sum_qn_q_iter");
+    }
 
-    res.push_back(time_res, std::to_string((int)t[i]));
+    res[i - 1] = Rcpp::wrap(time_res);
   }
 
   return res;
 }
 
-
 // [[Rcpp::export(".diagf_par")]]
-Rcpp::NumericVector diagf_par(Eigen::Map<Eigen::SparseMatrix<double> > &M, const int threads)
+Rcpp::NumericVector diagf_par(const Eigen::Map<Eigen::SparseMatrix<double> > &M,
+                              const int threads)
 {
   Rcpp::Rcout << "\nCached diagonal not found.\n";
-
   Rcpp::Rcout << "Performing setup. This can take several minutes...";
 
   Eigen::SparseLU<Eigen::SparseMatrix<double> > solver;
 
-  int sz = M.rows();
+  solver.compute(M);
+  if(solver.info() != Eigen::Success) {
+    Rcpp::stop("Decomposition failed in diagf_par");
+  }
 
+  int sz = M.rows();
   Eigen::VectorXd dg(sz);
 
-  solver.compute(M);
-
   Rcpp::Rcout << " Complete.\n";
-
   Rcpp::Rcout << "Calculating matrix inverse diagonal...\n";
 
   // Parallel run
-  std::vector<Eigen::VectorXd> xs(threads);
-  for (auto &x : xs)
-    x = Eigen::VectorXd::Zero(sz);
-
+  std::vector<Eigen::VectorXd> xs(threads, Eigen::VectorXd::Zero(sz));
   RcppThread::ProgressCounter progress(sz, 10);
 
   auto fun = [&] (unsigned int i){
     RcppThread::checkUserInterrupt();
 
     Eigen::VectorXd& ident = xs[(i * threads) / sz];
-
     ident(i) = 1;
+
     Eigen::VectorXd col = solver.solve(ident);
+    if(solver.info() != Eigen::Success) {
+      Rcpp::stop("Solver failed in diagf_par");
+    }
+
     dg(i) = col(i);
     ident(i) = 0;
-
     progress++;
   };
 
@@ -125,41 +149,42 @@ Rcpp::NumericVector diagf_par(Eigen::Map<Eigen::SparseMatrix<double> > &M, const
 }
 
 // [[Rcpp::export(".diagf_par_iter")]]
-Rcpp::NumericVector diagf_par_iter(Eigen::Map<Eigen::SparseMatrix<double> > &M, const int threads)
+Rcpp::NumericVector diagf_par_iter(const Eigen::Map<Eigen::SparseMatrix<double> > &M,
+                                   const int threads)
 {
   Rcpp::Rcout << "\nCached diagonal not found.\n";
-
   Rcpp::Rcout << "Performing setup. This can take several minutes...";
 
   Eigen::BiCGSTAB<Eigen::SparseMatrix<double>, Eigen::IncompleteLUT<double> > solver;
 
-  int sz = M.rows();
+  solver.compute(M);
+  if(solver.info() != Eigen::Success) {
+    Rcpp::stop("Decomposition failed in diagf_par_iter");
+  }
 
+  int sz = M.rows();
   Eigen::VectorXd dg(sz);
 
-  solver.compute(M);
-
   Rcpp::Rcout << " Complete.\n";
-
   Rcpp::Rcout << "Calculating matrix inverse diagonal...\n";
 
   // Parallel run
-  std::vector<Eigen::VectorXd> xs(threads);
-  for (auto &x : xs)
-    x = Eigen::VectorXd::Zero(sz);
-
+  std::vector<Eigen::VectorXd> xs(threads, Eigen::VectorXd::Zero(sz));
   RcppThread::ProgressCounter progress(sz, 10);
 
   auto fun = [&] (unsigned int i){
     RcppThread::checkUserInterrupt();
 
     Eigen::VectorXd& ident = xs[(i * threads) / sz];
-
     ident(i) = 1;
+
     Eigen::VectorXd col = solver.solve(ident);
+    if(solver.info() != Eigen::Success) {
+      Rcpp::stop("Solver failed in diagf_par_iter");
+    }
+
     dg(i) = col(i);
     ident(i) = 0;
-
     progress++;
   };
 
